import { redirect } from 'next/navigation'

import { GlobalLayout } from '@/components/global-layout'
import { Card } from '@/components/ui/card'
import { UserNameForm } from '@/components/user-name-form'
import { authOptions } from '@/lib/auth'
import { getCurrentUser } from '@/lib/session'

export const metadata = {
    title: 'Settings',
    description: 'Manage account and website settings.',
}

export default async function SettingsPage() {
    const session = await getCurrentUser()

    if (!session) {
        redirect(authOptions?.pages?.signIn || '/login')
    }

    return (
        <GlobalLayout
            mainContent={
                <Card className="w-full overflow-hidden p-6 md:p-12 space-y-6">
                    <h1 className="text-2xl font-semibold leading-none tracking-tight">Settings</h1>
                    <UserNameForm
                        user={{
                            id: session.id,
                            username: session.username || '',
                        }}
                    />
                </Card>
            }
        />
    )
}